@@ -251,27 +251,34 @@ void CDesktop::drawDesktop(QPainter *p)
     QRectF freqStepMin = renderer->boundsOnElement("Amount_Min");
     p->drawText(freqStepMin.x(), freqStepMin.y(),  QString("%1 Mhz").arg( CFMRadio::self().getStep()/1000) );
 
-
-    p->restore();
-
+    QRect FMIcon = renderer->boundsOnElement("FM_On_Icon").toAlignedRect();
+    FMIcon.adjust(4,4,4,4);
     if ( state )
     {
         // Draw stop button in place of FM icon
         renderer->render(p, "TX_Status_On", renderer->boundsOnElement("TX_Status_On"));
+        p->setOpacity(1.0);
         renderer->render(p, "FM_On_Icon", renderer->boundsOnElement("FM_On_Icon"));
-        startButton->setGeometry(renderer->boundsOnElement("FM_On_Icon").toAlignedRect());
+        p->setOpacity(0.0);
+        startButton->setGeometry(FMIcon);
     }
     else
     {
         // Draw start button in place of FM icon
         renderer->render(p, "TX_Status_Off", renderer->boundsOnElement("TX_Status_Off"));
+        p->setOpacity(1.0);
         renderer->render(p, "FM_Off_Icon", renderer->boundsOnElement("FM_Off_Icon"));
-        startButton->setGeometry(renderer->boundsOnElement("FM_On_Icon").toAlignedRect());
+        p->setOpacity(0.0);
+        startButton->setGeometry(FMIcon);
     }
+    QRect next = renderer->boundsOnElement("Plus").toAlignedRect();
+    next.adjust(4,4,4,4);
+    QRect prev = renderer->boundsOnElement("Min").toAlignedRect();
+    prev.adjust(4,4,4,4);
+    nextButton->setGeometry(next);
+    previousButton->setGeometry(prev);
 
-    nextButton->setGeometry(renderer->boundsOnElement("Plus").toAlignedRect());
-    previousButton->setGeometry(renderer->boundsOnElement("Min").toAlignedRect());
-
+    p->restore();
 }
 
 void CDesktop::slotFMTXChanged(QString type, QString status)
@@ -291,15 +298,15 @@ void CDesktop::slotToggleFM(bool checked){
 }
 
 void CDesktop::slotClickedNext(bool checked){
-    int stepFreq = CFMRadio::self().getStep();
-    int curFreq = CFMRadio::self().getFrequency();
-    CFMRadio::self().setFrequency(curFreq + stepFreq);
+    CFMRadio::self().setFreqUp();
+    dirty = true;
+    update();
     qDebug() << "Current frequency=" << CFMRadio::self().getFrequency();
 }
 
 void CDesktop::slotClickedPrevious(bool checked){
-    int stepFreq = CFMRadio::self().getStep();
-    int curFreq = CFMRadio::self().getFrequency();
-    CFMRadio::self().setFrequency(curFreq - stepFreq);
+    CFMRadio::self().setFreqDown();
+    dirty = true;
+    update();
     qDebug() << "Current frequency=" << CFMRadio::self().getFrequency();
 }
