@@ -2,12 +2,7 @@
 #define CSMS_H
 
 #include "IRdsText.h"
-#include <QMessageManager>
-#include <QMessage>
-#include <QMessageAddress>
-#include <QMessageContentContainerId>
-
-QTM_USE_NAMESPACE
+#include <QtDBus>
 
 class CSms : public IRdsText
 {
@@ -27,6 +22,7 @@ public:
     // state plug on or off
     void    setEnable(bool value);
     bool getEnable();
+    bool getState();
     // connect plug
     void setConnect(int value);
 
@@ -48,10 +44,11 @@ private:
     int timeout;
     // Pluig status
     bool state;
-    // Message class
-    QMessageManager *smsManager;
+    // Tx connect state
+    bool connect;
+
 private slots:
-    void slotComingChanged(QMessageId id,QMessageManager::NotificationFilterIdSet filters);
+    void slotComingChanged(QString ukn,uint id,QString type,QString from ,QString text,QDBusVariant var);
 
 };
 
